r_jupyter: Jupyter kernel for R
===============================

Description
-----------

This package installs IRkernel, the R Jupyter kernel.

It gets installed via R's package installer on top of Jupyter.

License
-------

MIT

Upstream Contact
----------------

- https://github.com/IRkernel/IRkernel
- https://irkernel.github.io/

Dependencies
------------

- R
- notebook
